# 07 Multi-Link Arms: Lie Algebra and Propagated States

!!! Warning "Work In Progress"
    This tutorial is under development!

## Further Reading

- [API Reference: Lie algebra](../Reference/symbolic/expr/lie/index.md)
- [Three-link arm Example](../Examples/arm/three_link_arm.md)
